@@ -84,12 +84,13 @@ def instrument_methods(method_wrappers):
                 logger.debug('instrumenting method %s', qualified_method_name)
                 wrap_method(class_def, method_name, method_wrapper)
             else:
-                logger.info('%s not instrumented because not found', fully_qualified_class_name)
+                logger.warn('%s not instrumented because not found', fully_qualified_class_name)
         except ImportError:
             logger.debug('could not instrument %s', qualified_method_name)
-            logger.info('%s not instrumented because not found', fully_qualified_class_name)
+            logger.warn('%s not instrumented because not found', fully_qualified_class_name)
         except AttributeError:
             logger.warn('could not instrument %s', qualified_method_name)
+            logger.exception('details')
 
 
 def override_classes(overridden_classes, wrapped):
@@ -106,10 +107,10 @@ def override_classes(overridden_classes, wrapped):
                 logger.debug('instrumenting class %s', fully_qualified_class_name)
                 wrap_methods(cls, targeted_methods, wrapped)
             else:
-                logger.info('%s not overridden because not found', fully_qualified_class_name)
+                logger.warn('%s not overridden because not found', fully_qualified_class_name)
         except ImportError:
             logger.debug('could not override %s', fully_qualified_class_name)
-            logger.info('%s not overridden because not found', fully_qualified_class_name)
+            logger.warn('%s not overridden because not found', fully_qualified_class_name)
 
 
 def wrap_returned_instances(original_method, overrides):
@@ -259,9 +260,9 @@ def _eval(args, keywords, expressions):
     final_failure = Exception
     if expressions is None:
         return None
-    for expression in expressions.split('|') if isinstance(expressions, basestring) else [expressions]:
+    for expression in expressions.split('|') if isinstance(expressions, six.string_types) else [expressions]:
         try:
-            if isinstance(expression, (int, long)):
+            if isinstance(expression, six.integer_types):
                 value = args[expression]
             elif expression.startswith('self'):
                 v = {'self': args[0]}
@@ -384,7 +385,7 @@ def generator_wrapper_factory(recorder, state=None, enable_if='web', disable_if=
                         context.push_state(state)
                         t = time.time()
                         try:
-                            v = gen.next()
+                            v = six.next(gen)
                         finally:
                             elapsed += time.time() - t
                             context.pop_state(state)
@@ -418,10 +419,10 @@ def contextmanager_wrapper_factory(context_manager, mapping=None, state=None, en
         @wraps(f)
         def wrapper(*args, **keywords):
             if _should_be_instrumented(state, enable_if, disable_if):
-                tag_pairs = _build_key(mapping, args, keywords)
+                # Tags are ignored for now
+                # tag_pairs = _build_key(mapping, args, keywords)
                 try:
                     context.push_state(state)
-                    context.push_tags(tag_pairs)
                     with context_manager(*args, **keywords):
                         if hasattr(f, '__get__'):
                             self = args[0].__subject__ if hasattr(args[0], '__subject__') else args[0]
@@ -429,7 +430,6 @@ def contextmanager_wrapper_factory(context_manager, mapping=None, state=None, en
                         else:
                             return f(*args, **keywords)
                 finally:
-                    context.pop_tags(tag_pairs)
                     context.pop_state(state)
             else:
                 return f(*args, **keywords)
